@@ -30,13 +30,16 @@
 
 
 #' @title
-#' Installation-Related Utilities
+#' Installation-Related Utilities [DEPRECATED]
 #'
 #' @description
 #' These functions are responsible for checking and guaranteeing
 #' that the ICU data library (icudt) is available and that \pkg{stringi}
 #' is ready to use.
 #'
+#' These functions are deprecated and will no longer be available
+#' in future \pkg{stringi} releases.
+#'
 #' @details
 #' ICU makes use of a wide variety of data tables to provide many
 #' of its services. Examples include converter mapping tables,
@@ -80,6 +83,9 @@
 stri_install_check <- function(silent=FALSE) {
    stopifnot(is.logical(silent), length(silent) == 1)
 
+   warning("THIS FUNCTION IS DEPRECATED")
+   # this function may stay as-is, but should no longer be exported in the future
+
    allok <- tryCatch({
       if (!silent) message(stri_info(TRUE)) # this may also throw an error
 
@@ -103,7 +109,6 @@ stri_install_check <- function(silent=FALSE) {
 
 #' @rdname stri_install
 #' @export
-#' @importFrom tools md5sum
 stri_install_icudt <- function(check=TRUE, outpath=NULL, inpath=NULL) {
    stopifnot(is.logical(check), length(check) == 1, !is.na(check))
    if (check && stri_install_check(TRUE)) {
@@ -111,6 +116,12 @@ stri_install_icudt <- function(check=TRUE, outpath=NULL, inpath=NULL) {
       return(invisible(TRUE))
    }
 
+   if (check) # install.libs.R calls it with check=FALSE
+      warning("THIS FUNCTION IS DEPRECATED")
+   # this function should be removed
+   # remember about importFrom tools md5sum -> stringi-package.R
+   # use this very code in install.libs.R directly
+
    if (is.null(outpath))
       outpath <- file.path(path.package("stringi"), "libs")
    stopifnot(is.character(outpath), length(outpath) == 1, file.exists(outpath))
@@ -179,6 +190,5 @@ stri_install_icudt <- function(check=TRUE, outpath=NULL, inpath=NULL) {
 
    suppressWarnings(file.remove(outfname))
    message("icudt has been installed successfully")
-   message("restart R to apply changes")
    invisible(TRUE)
 }
